/* auth-notification.c generated by valac 0.23.2.10-fed12, the Vala compiler
 * generated from auth-notification.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <libgd/gd.h>
#include <gtk/gtk.h>
#include <stdlib.h>
#include <string.h>
#include <clutter/clutter.h>
#include <clutter-gtk/clutter-gtk.h>
#include <gio/gio.h>
#include <gdk/gdk.h>


#define BOXES_TYPE_AUTH_NOTIFICATION (boxes_auth_notification_get_type ())
#define BOXES_AUTH_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotification))
#define BOXES_AUTH_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotificationClass))
#define BOXES_IS_AUTH_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_AUTH_NOTIFICATION))
#define BOXES_IS_AUTH_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_AUTH_NOTIFICATION))
#define BOXES_AUTH_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotificationClass))

typedef struct _BoxesAuthNotification BoxesAuthNotification;
typedef struct _BoxesAuthNotificationClass BoxesAuthNotificationClass;
typedef struct _BoxesAuthNotificationPrivate BoxesAuthNotificationPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block9Data Block9Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_CLUTTER_WIDGET (boxes_clutter_widget_get_type ())
#define BOXES_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidget))
#define BOXES_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))
#define BOXES_IS_CLUTTER_WIDGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_IS_CLUTTER_WIDGET_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_CLUTTER_WIDGET))
#define BOXES_CLUTTER_WIDGET_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_CLUTTER_WIDGET, BoxesClutterWidgetClass))

typedef struct _BoxesClutterWidget BoxesClutterWidget;
typedef struct _BoxesClutterWidgetClass BoxesClutterWidgetClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_SEARCHBAR (boxes_searchbar_get_type ())
#define BOXES_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbar))
#define BOXES_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))
#define BOXES_IS_SEARCHBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SEARCHBAR))
#define BOXES_IS_SEARCHBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SEARCHBAR))
#define BOXES_SEARCHBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SEARCHBAR, BoxesSearchbarClass))

typedef struct _BoxesSearchbar BoxesSearchbar;
typedef struct _BoxesSearchbarClass BoxesSearchbarClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_EMPTY_BOXES (boxes_empty_boxes_get_type ())
#define BOXES_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxes))
#define BOXES_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))
#define BOXES_IS_EMPTY_BOXES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_IS_EMPTY_BOXES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_EMPTY_BOXES))
#define BOXES_EMPTY_BOXES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_EMPTY_BOXES, BoxesEmptyBoxesClass))

typedef struct _BoxesEmptyBoxes BoxesEmptyBoxes;
typedef struct _BoxesEmptyBoxesClass BoxesEmptyBoxesClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_COLLECTION_FILTER (boxes_collection_filter_get_type ())
#define BOXES_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilter))
#define BOXES_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))
#define BOXES_IS_COLLECTION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_IS_COLLECTION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_FILTER))
#define BOXES_COLLECTION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_FILTER, BoxesCollectionFilterClass))

typedef struct _BoxesCollectionFilter BoxesCollectionFilter;
typedef struct _BoxesCollectionFilterClass BoxesCollectionFilterClass;

#define BOXES_TYPE_COLLECTION_VIEW (boxes_collection_view_get_type ())
#define BOXES_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionView))
#define BOXES_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))
#define BOXES_IS_COLLECTION_VIEW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_IS_COLLECTION_VIEW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_VIEW))
#define BOXES_COLLECTION_VIEW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_VIEW, BoxesCollectionViewClass))

typedef struct _BoxesCollectionView BoxesCollectionView;
typedef struct _BoxesCollectionViewClass BoxesCollectionViewClass;

struct _BoxesAuthNotification {
	GdNotification parent_instance;
	BoxesAuthNotificationPrivate * priv;
};

struct _BoxesAuthNotificationClass {
	GdNotificationClass parent_class;
};

typedef void (*BoxesAuthNotificationAuthFunc) (const gchar* username, const gchar* password, void* user_data);
struct _BoxesAuthNotificationPrivate {
	GtkLabel* title_label;
	GtkLabel* username_label;
	GtkEntry* username_entry;
	GtkEntry* password_entry;
	GtkButton* auth_button;
	BoxesAuthNotificationAuthFunc auth_func;
	gpointer auth_func_target;
	GDestroyNotify auth_func_target_destroy_notify;
	gboolean auth_pressed;
};

typedef void (*BoxesNotificationCancelFunc) (void* user_data);
struct _Block9Data {
	int _ref_count_;
	BoxesAuthNotification* self;
	BoxesNotificationCancelFunc cancel_func;
	gpointer cancel_func_target;
	GDestroyNotify cancel_func_target_destroy_notify;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	ClutterActor* (*get_actor) (BoxesUI* self);
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesApp {
	GObject parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	BoxesClutterWidget* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesSearchbar* searchbar;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesEmptyBoxes* empty_boxes;
	BoxesCollection* collection;
	BoxesCollectionFilter* filter;
	BoxesCollectionView* view;
};

struct _BoxesAppClass {
	GObjectClass parent_class;
};


static gpointer boxes_auth_notification_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_auth_notification_get_type (void) G_GNUC_CONST;
#define BOXES_AUTH_NOTIFICATION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotificationPrivate))
enum  {
	BOXES_AUTH_NOTIFICATION_DUMMY_PROPERTY
};
BoxesAuthNotification* boxes_auth_notification_new (const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gboolean need_username);
BoxesAuthNotification* boxes_auth_notification_construct (GType object_type, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gboolean need_username);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static void __lambda27_ (Block9Data* _data9_);
static void ___lambda27__gd_notification_dismissed (GdNotification* _sender, gpointer self);
static gboolean boxes_auth_notification_on_entry_focus_in_event (BoxesAuthNotification* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_clutter_widget_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_searchbar_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_empty_boxes_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
GType boxes_collection_filter_get_type (void) G_GNUC_CONST;
GType boxes_collection_view_get_type (void) G_GNUC_CONST;
void boxes_searchbar_set_enable_key_handler (BoxesSearchbar* self, gboolean value);
static gboolean _boxes_auth_notification_on_entry_focus_in_event_gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static gboolean boxes_auth_notification_on_entry_focus_out_event (BoxesAuthNotification* self);
static gboolean _boxes_auth_notification_on_entry_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self);
static void boxes_auth_notification_on_username_entry_map (BoxesAuthNotification* self);
static void _boxes_auth_notification_on_username_entry_map_gtk_widget_map (GtkWidget* _sender, gpointer self);
static void boxes_auth_notification_on_username_entry_activated (BoxesAuthNotification* self);
static void _boxes_auth_notification_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_auth_notification_on_password_entry_activated (BoxesAuthNotification* self);
static void _boxes_auth_notification_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self);
static void boxes_auth_notification_on_auth_button_clicked (BoxesAuthNotification* self);
static void _boxes_auth_notification_on_auth_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_auth_notification_finalize (GObject* obj);


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return _data9_;
#line 338 "auth-notification.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 347 "auth-notification.c"
		BoxesAuthNotification* self;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		self = _data9_->self;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		(_data9_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data9_->cancel_func_target_destroy_notify (_data9_->cancel_func_target), NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_data9_->cancel_func = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_data9_->cancel_func_target = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_data9_->cancel_func_target_destroy_notify = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_g_object_unref0 (self);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		g_slice_free (Block9Data, _data9_);
#line 363 "auth-notification.c"
	}
}


static void __lambda27_ (Block9Data* _data9_) {
	BoxesAuthNotification* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp1_ = FALSE;
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self = _data9_->self;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp1_ = self->priv->auth_pressed;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	if (!_tmp1_) {
#line 378 "auth-notification.c"
		BoxesNotificationCancelFunc _tmp2_ = NULL;
		void* _tmp2__target = NULL;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp2_ = _data9_->cancel_func;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp2__target = _data9_->cancel_func_target;
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp0_ = _tmp2_ != NULL;
#line 387 "auth-notification.c"
	} else {
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp0_ = FALSE;
#line 391 "auth-notification.c"
	}
#line 30 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	if (_tmp0_) {
#line 395 "auth-notification.c"
		BoxesNotificationCancelFunc _tmp3_ = NULL;
		void* _tmp3__target = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp3_ = _data9_->cancel_func;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp3__target = _data9_->cancel_func_target;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp3_ (_tmp3__target);
#line 404 "auth-notification.c"
	}
}


static void ___lambda27__gd_notification_dismissed (GdNotification* _sender, gpointer self) {
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	__lambda27_ (self);
#line 412 "auth-notification.c"
}


BoxesAuthNotification* boxes_auth_notification_construct (GType object_type, const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gboolean need_username) {
	BoxesAuthNotification * self = NULL;
	Block9Data* _data9_;
	BoxesNotificationCancelFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
	GtkLabel* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	GtkLabel* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	GtkEntry* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
	BoxesAuthNotificationAuthFunc _tmp7_ = NULL;
	void* _tmp7__target = NULL;
	GDestroyNotify _tmp7__target_destroy_notify = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_val_if_fail (auth_string != NULL, NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_ = g_slice_new0 (Block9Data);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->_ref_count_ = 1;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = cancel_func;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0__target = cancel_func_target;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	(_data9_->cancel_func_target_destroy_notify == NULL) ? NULL : (_data9_->cancel_func_target_destroy_notify (_data9_->cancel_func_target), NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func_target = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func_target_destroy_notify = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func = _tmp0_;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func_target = _tmp0__target;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->cancel_func_target_destroy_notify = cancel_func_target_destroy_notify;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self = (BoxesAuthNotification*) g_object_new (object_type, NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_->self = g_object_ref (self);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_object_set ((GdNotification*) self, "show-close-button", FALSE, NULL);
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp1_ = self->priv->title_label;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp2_ = auth_string;
#line 27 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_label_set_label (_tmp1_, _tmp2_);
#line 29 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_signal_connect_data ((GdNotification*) self, "dismissed", (GCallback) ___lambda27__gd_notification_dismissed, block9_data_ref (_data9_), (GClosureNotify) block9_data_unref, 0);
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp3_ = self->priv->username_label;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp4_ = need_username;
#line 34 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp3_, _tmp4_);
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp5_ = self->priv->username_entry;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp6_ = need_username;
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_set_visible ((GtkWidget*) _tmp5_, _tmp6_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp7_ = auth_func;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp7__target = auth_func_target;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp7__target_destroy_notify = auth_func_target_destroy_notify;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	auth_func_target_destroy_notify = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	(self->priv->auth_func_target_destroy_notify == NULL) ? NULL : (self->priv->auth_func_target_destroy_notify (self->priv->auth_func_target), NULL);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target_destroy_notify = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func = _tmp7_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target = _tmp7__target;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target_destroy_notify = _tmp7__target_destroy_notify;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	(auth_func_target_destroy_notify == NULL) ? NULL : (auth_func_target_destroy_notify (auth_func_target), NULL);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	auth_func = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	auth_func_target = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	auth_func_target_destroy_notify = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	block9_data_unref (_data9_);
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_data9_ = NULL;
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return self;
#line 516 "auth-notification.c"
}


BoxesAuthNotification* boxes_auth_notification_new (const gchar* auth_string, BoxesAuthNotificationAuthFunc auth_func, void* auth_func_target, GDestroyNotify auth_func_target_destroy_notify, BoxesNotificationCancelFunc cancel_func, void* cancel_func_target, GDestroyNotify cancel_func_target_destroy_notify, gboolean need_username) {
#line 22 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return boxes_auth_notification_construct (BOXES_TYPE_AUTH_NOTIFICATION, auth_string, auth_func, auth_func_target, auth_func_target_destroy_notify, cancel_func, cancel_func_target, cancel_func_target_destroy_notify, need_username);
#line 523 "auth-notification.c"
}


static gboolean boxes_auth_notification_on_entry_focus_in_event (BoxesAuthNotification* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = boxes_app_app;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, FALSE);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	result = FALSE;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return result;
#line 543 "auth-notification.c"
}


static gboolean _boxes_auth_notification_on_entry_focus_in_event_gtk_widget_focus_in_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = boxes_auth_notification_on_entry_focus_in_event ((BoxesAuthNotification*) self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return result;
#line 552 "auth-notification.c"
}


static gboolean boxes_auth_notification_on_entry_focus_out_event (BoxesAuthNotification* self) {
	gboolean result = FALSE;
	BoxesApp* _tmp0_ = NULL;
	BoxesSearchbar* _tmp1_ = NULL;
#line 48 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = boxes_app_app;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp1_ = _tmp0_->searchbar;
#line 49 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_searchbar_set_enable_key_handler (_tmp1_, TRUE);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	result = FALSE;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return result;
#line 572 "auth-notification.c"
}


static gboolean _boxes_auth_notification_on_entry_focus_out_event_gtk_widget_focus_out_event (GtkWidget* _sender, GdkEventFocus* event, gpointer self) {
	gboolean result;
	result = boxes_auth_notification_on_entry_focus_out_event ((BoxesAuthNotification*) self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	return result;
#line 581 "auth-notification.c"
}


static void boxes_auth_notification_on_username_entry_map (BoxesAuthNotification* self) {
	GtkEntry* _tmp0_ = NULL;
#line 55 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_if_fail (self != NULL);
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = self->priv->username_entry;
#line 56 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp0_);
#line 593 "auth-notification.c"
}


static void _boxes_auth_notification_on_username_entry_map_gtk_widget_map (GtkWidget* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_auth_notification_on_username_entry_map ((BoxesAuthNotification*) self);
#line 600 "auth-notification.c"
}


static void boxes_auth_notification_on_username_entry_activated (BoxesAuthNotification* self) {
	GtkEntry* _tmp0_ = NULL;
#line 60 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_if_fail (self != NULL);
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = self->priv->password_entry;
#line 61 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_grab_focus ((GtkWidget*) _tmp0_);
#line 612 "auth-notification.c"
}


static void _boxes_auth_notification_on_username_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_auth_notification_on_username_entry_activated ((BoxesAuthNotification*) self);
#line 619 "auth-notification.c"
}


static void boxes_auth_notification_on_password_entry_activated (BoxesAuthNotification* self) {
	GtkButton* _tmp0_ = NULL;
#line 65 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_if_fail (self != NULL);
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = self->priv->auth_button;
#line 66 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_signal_emit_by_name (_tmp0_, "activate");
#line 631 "auth-notification.c"
}


static void _boxes_auth_notification_on_password_entry_activated_gtk_entry_activate (GtkEntry* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_auth_notification_on_password_entry_activated ((BoxesAuthNotification*) self);
#line 638 "auth-notification.c"
}


static void boxes_auth_notification_on_auth_button_clicked (BoxesAuthNotification* self) {
	BoxesAuthNotificationAuthFunc _tmp0_ = NULL;
	void* _tmp0__target = NULL;
#line 70 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_return_if_fail (self != NULL);
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0_ = self->priv->auth_func;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_tmp0__target = self->priv->auth_func_target;
#line 71 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	if (_tmp0_ != NULL) {
#line 653 "auth-notification.c"
		BoxesAuthNotificationAuthFunc _tmp1_ = NULL;
		void* _tmp1__target = NULL;
		GtkEntry* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		GtkEntry* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp1_ = self->priv->auth_func;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp1__target = self->priv->auth_func_target;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp2_ = self->priv->username_entry;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp3_ = gtk_entry_get_text (_tmp2_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp4_ = self->priv->password_entry;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp5_ = gtk_entry_get_text (_tmp4_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
		_tmp1_ (_tmp3_, _tmp5_, _tmp1__target);
#line 674 "auth-notification.c"
	}
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_pressed = TRUE;
#line 75 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gd_notification_dismiss ((GdNotification*) self);
#line 680 "auth-notification.c"
}


static void _boxes_auth_notification_on_auth_button_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_auth_notification_on_auth_button_clicked ((BoxesAuthNotification*) self);
#line 687 "auth-notification.c"
}


static void boxes_auth_notification_class_init (BoxesAuthNotificationClass * klass) {
	gint BoxesAuthNotification_private_offset;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	boxes_auth_notification_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	g_type_class_add_private (klass, sizeof (BoxesAuthNotificationPrivate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_auth_notification_finalize;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	BoxesAuthNotification_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/auth-notification.ui");
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "title_label", FALSE, BoxesAuthNotification_private_offset + G_STRUCT_OFFSET (BoxesAuthNotificationPrivate, title_label));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "username_label", FALSE, BoxesAuthNotification_private_offset + G_STRUCT_OFFSET (BoxesAuthNotificationPrivate, username_label));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "username_entry", FALSE, BoxesAuthNotification_private_offset + G_STRUCT_OFFSET (BoxesAuthNotificationPrivate, username_entry));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "password_entry", FALSE, BoxesAuthNotification_private_offset + G_STRUCT_OFFSET (BoxesAuthNotificationPrivate, password_entry));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "auth_button", FALSE, BoxesAuthNotification_private_offset + G_STRUCT_OFFSET (BoxesAuthNotificationPrivate, auth_button));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_focus_in_event", G_CALLBACK(_boxes_auth_notification_on_entry_focus_in_event_gtk_widget_focus_in_event));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_entry_focus_out_event", G_CALLBACK(_boxes_auth_notification_on_entry_focus_out_event_gtk_widget_focus_out_event));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_username_entry_map", G_CALLBACK(_boxes_auth_notification_on_username_entry_map_gtk_widget_map));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_username_entry_activated", G_CALLBACK(_boxes_auth_notification_on_username_entry_activated_gtk_entry_activate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_password_entry_activated", G_CALLBACK(_boxes_auth_notification_on_password_entry_activated_gtk_entry_activate));
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_auth_button_clicked", G_CALLBACK(_boxes_auth_notification_on_auth_button_clicked_gtk_button_clicked));
#line 725 "auth-notification.c"
}


static void boxes_auth_notification_instance_init (BoxesAuthNotification * self) {
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv = BOXES_AUTH_NOTIFICATION_GET_PRIVATE (self);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 734 "auth-notification.c"
}


static void boxes_auth_notification_finalize (GObject* obj) {
	BoxesAuthNotification * self;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_AUTH_NOTIFICATION, BoxesAuthNotification);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_g_object_unref0 (self->priv->title_label);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_g_object_unref0 (self->priv->username_label);
#line 13 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_g_object_unref0 (self->priv->username_entry);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_g_object_unref0 (self->priv->password_entry);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	_g_object_unref0 (self->priv->auth_button);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	(self->priv->auth_func_target_destroy_notify == NULL) ? NULL : (self->priv->auth_func_target_destroy_notify (self->priv->auth_func_target), NULL);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target = NULL;
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	self->priv->auth_func_target_destroy_notify = NULL;
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/auth-notification.vala"
	G_OBJECT_CLASS (boxes_auth_notification_parent_class)->finalize (obj);
#line 762 "auth-notification.c"
}


GType boxes_auth_notification_get_type (void) {
	static volatile gsize boxes_auth_notification_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_auth_notification_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesAuthNotificationClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_auth_notification_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesAuthNotification), 0, (GInstanceInitFunc) boxes_auth_notification_instance_init, NULL };
		GType boxes_auth_notification_type_id;
		boxes_auth_notification_type_id = g_type_register_static (gd_notification_get_type (), "BoxesAuthNotification", &g_define_type_info, 0);
		g_once_init_leave (&boxes_auth_notification_type_id__volatile, boxes_auth_notification_type_id);
	}
	return boxes_auth_notification_type_id__volatile;
}



